#!/bin/bash
#
# deleteNode.sh - remove a TeamCall CSTAServer node under Linux
#                 (supports Debian, Suse and Ubuntu distributions)
#
# Copyright (c) 2006, 2010-2011, 2017 by ilink Kommunikationssysteme GmbH.  All Rights Reserved.
#


SCRIPT_NAME="deleteNode.sh"
PATH=$PATH:/usr/bin:/usr/sbin:/sbin


# Check for root permissions
perm=$(id -u)
if [ "$perm" != "0" ]; then
    echo "You must be root to run this script"
    echo "Deleting TeamCall CSTAServer node canceled"
    exit 1
fi


# Path of TeamCall directory e.g. /usr/local/ilink/teamcall
cd $(dirname "$0")
TCSPATH=$(pwd | sed -e s%/bin%%g)
#echo "TCSPATH -> $TCSPATH"
cd - > /dev/null


# Default variables
NODENAME=""


# Determine Linux distribution
DIST="unknown"
if [ "`lsb_release -i | grep -i debian`" ]; then
	DIST="debian"
elif [ "`lsb_release -i | grep -i suse`" ]; then
	DIST="suse"
elif [ "`lsb_release -i | grep -i ubuntu`" ]; then
	DIST="ubuntu"
else
	echo "Distribution not supported!"
	echo "($SCRIPT_NAME only supports Debian, Suse and Ubuntu distributions)"
	exit 0
fi


# Get and confirm all parameters
while [ "$checkParameters" != "OK" ]
do
	clear
	echo "Delete a TeamCall CSTAServer node"
	echo ""

	echo -e "Node name of the TeamCall CSTAServer instance [$NODENAME]:\c "
	read NODENAME_TMP

	if [ "$NODENAME_TMP" != "" ]; then
   	   NODENAME="$NODENAME_TMP"
	fi

	echo "----------------------------------------------------------"
	echo " Review the settings:"
	echo ""
	echo " TeamCall CSTAServer node to be deleted: $NODENAME"
	echo ""
	echo "----------------------------------------------------------"

	checker="0"	
	echo -e "Are the settings correct? Then type OK: \c"
	read checker

	if [ "$checker" = "OK" ]; then
   	   checkParameters="OK"
	fi
done


# Check for existence of the node
if [ ! -d "$TCSPATH/node_$NODENAME" ]; then
	echo
	echo "The node $NODENAME does not exist!"
	echo "Can't delete this node!"
	echo ""
	exit -1
fi


# Stop TeamCall process
echo "Stopping TeamCall CSTAServer instance $NODENAME ..."
/etc/init.d/CSTAServer_$NODENAME stop > /dev/null


# Delete init links (distribution specific)
if [ "$DIST" = "debian" -o "$DIST" = "ubuntu" ]; then
	rm -rf "/etc/init.d/CSTAServer_$NODENAME"
	update-rc.d -f "CSTAServer_$NODENAME" remove > /dev/null 2>&1
fi
if [ "$DIST" = "suse" ]; then
	chkconfig --del "CSTAServer_$NODENAME" > /dev/null 2>&1
	rm -rf "/etc/init.d/CSTAServer_$NODENAME"
fi
echo "Start/stop links removed ..."


# Delete node directory structure
rm -rf "$TCSPATH/node_$NODENAME"
echo "Directory structure '$TCSPATH/node_$NODENAME' deleted ..."

